NAME
Chart::GGPlot::Guide - Role for guide
VERSION
version 0.0001
ATTRIBUTES
title
A string indicating a title of the guide. If an empty string, the title is not show. By default (undef) the name of the scale object or the name specified in labs() is used for the title.
AUTHOR
Stephan Loyd <sloyd@cpan.org>
COPYRIGHT AND LICENSE
This software is copyright (c) 2019 by Stephan Loyd.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.